@@ -983,13 +983,13 @@ sub open_database {
   # do a little extra stuff the first time we see a new database
   unless ($self->{databases_seen}{$db}++) {
       my $refclass = $self->setting('reference class');
-      eval {$db->default_class($refclass)} if $refclass;
+      $db->default_class($refclass) if $refclass && $db->can('default_class');
       $db->strict_bounds_checking(1) if $db->can('strict_bounds_checking');
       $db->absolute(1)               if $db->can('absolute');
 
       unless ($track eq 'general') {
 	  my $default = $self->open_database();  # I hope we don't get into a loop here
-	  eval {$db->dna_accessor($default)} unless $default eq $db;
+	  $db->dna_accessor($default) if $default ne $db && $db->can('dna_accessor');
       }
 
   }
