@@ -168,7 +168,6 @@ sub request_panels {
 
       open STDIN, "</dev/null" or die "Couldn't reopen stdin";
       open STDOUT,">/dev/null" or die "Couldn't reopen stdout";
-      POSIX::setsid()          or die "Couldn't start new session";
 
       if ( $do_local && $do_remote ) {
           if ( $render->fork() ) {
@@ -332,6 +331,7 @@ sub make_requests {
 			     $label ],
 	    -cache_time => $cache_time
         );
+
         $d{$label} = $cache_object;
     }
 
@@ -372,7 +372,7 @@ sub render_tracks {
     my $requests = shift;
     my $args     = shift;
     my %result;
-    
+
     for my $label ( keys %$requests ) {
         my $data   = $requests->{$label};
         my $gd     = eval{$data->gd} or next;
@@ -382,7 +382,7 @@ sub render_tracks {
         my $height = $data->height;
         my $url    = $self->source->generate_image($gd);
 
-        # for debugging
+	# for debugging
         my $status = $data->status;
 
         $result{$label} = $self->wrap_rendered_track(
@@ -464,14 +464,14 @@ sub wrap_rendered_track {
     my $share_this_track = $self->language->translate('SHARE_THIS_TRACK')
         || "Share this track";
 
-    my $configure_this_track = '';
-    $configure_this_track .= $self->language->translate('CONFIGURE_THIS_TRACK')
-        || "Configure this track";
-
     my $download_this_track = '';
     $download_this_track .= $self->language->translate('DOWNLOAD_THIS_TRACK')
         || "<b>Download this track</b>";
 
+    my $configure_this_track = '';
+    $configure_this_track .= $self->language->translate('CONFIGURE_THIS_TRACK')
+        || "Configure this track";
+
     my $about_this_track = '';
     $about_this_track .= $self->language->translate('ABOUT_THIS_TRACK',$label)
         || "<b>About this track</b>";
@@ -562,12 +562,6 @@ sub wrap_rendered_track {
             }
         ),
 
-        $config_click ? img({   -src         => $configure,
-				-style       => 'cursor:pointer',
-				-onmousedown => $config_click,
-				$self->if_not_ipad(-onMouseOver => "$balloon_style.showTooltip(event,'$configure_this_track')"),
-			    })
-	              : '',
         $download_click ? img({   -src         => $download,
 				  -style       => 'cursor:pointer',
 				  -onmousedown => $download_click,
@@ -575,6 +569,14 @@ sub wrap_rendered_track {
 						     "$balloon_style.showTooltip(event,'$download_this_track')"),
 			      })
 	                 : '',
+
+        $config_click ? img({   -src         => $configure,
+				-style       => 'cursor:pointer',
+				-onmousedown => $config_click,
+				$self->if_not_ipad(-onMouseOver => "$balloon_style.showTooltip(event,'$configure_this_track')"),
+			    })
+	              : '',
+
         img({   -src         => $help,
                  -style       => 'cursor:pointer',
                  -onmousedown => $help_click,
@@ -695,9 +697,13 @@ sub wrap_rendered_track {
 
 
     my $subtrack_labels = join '',map {
-	my ($label,$left,$top) = @$_;
-	$left = PAD_DETAIL_SIDES;
-	div({-class=>'subtrack',-style=>"top:${top}px;left:${left}px;background-color:white"},$label);
+	my ($label,$left,$top,undef,undef,$color) = @$_;
+	$left -= $source->global_setting('pad_left') + PAD_DETAIL_SIDES;
+	$left = 3 if $left < 3;
+	my ($r,$g,$b,$a) = $color =~ /rgba\((\d+),(\d+),(\d+),([\d.]+)/;
+	$a = 0.60 if $a > 0.75;
+	my $fgcolor = $a <= 0.5 ? 'black' : ($r+$g+$b)/3 > 128 ? 'black' : 'white';
+	div({-class=>'subtrack',-style=>"top:${top}px;left:${left}px;color:$fgcolor;background-color:rgba($r,$g,$b,$a)"},$label);
     } @$titles;
 
     my $html = div({-class=>'centered_block',
@@ -1443,6 +1449,7 @@ sub run_local_requests {
     	    delete $children{$pid} if $children{$pid};
     	}
     };
+    local $SIG{TERM}    = sub { warn "[$$] GBrowse render process terminated"; exit 0; };
 
     my $max_processes = $self->source->global_setting('max_render_processes')
 	|| MAX_PROCESSES;
@@ -1481,7 +1488,6 @@ sub run_local_requests {
 	my $key = $source->setting( $base => 'key' ) || '' ;
 	my @nopad = ();
         my $panel_args = $requests->{$label}->panel_args;
-
 	
         my $panel
             = Bio::Graphics::Panel->new( @$panel_args, @keystyle, @nopad );
@@ -1514,7 +1520,7 @@ sub run_local_requests {
 		    my $featurefile_select = $args->{featurefile_select}
 		    || $self->feature_file_select($section);
 			
-		    if ( ref $file and $panel ) {
+ 		    if ( ref $file and $panel ) {
 			$self->add_feature_file(
 			    file     => $file,
 			    panel    => $panel,
@@ -1549,8 +1555,14 @@ sub run_local_requests {
 		$gd     = $panel->gd;
 		warn "render gd($label): ",time()-$time," seconds " if BENCHMARK;
 
-		$titles = $panel->key_boxes;
-		foreach (@$titles) {splice (@$_,-1)}  # don't want to store all track config data to cache!
+		$titles    = $panel->key_boxes;
+		foreach (@$titles) {
+		    my $index = $_->[5]->bgcolor;  # record track config bgcolor
+		    my ($r,$g,$b) = $gd->rgb($index);
+		    my $alpha     = $_->[5]->default_opacity;
+		    $_->[5]       =  "rgba($r,$g,$b,$alpha)";
+		}  # don't want to store all track config data to cache!
+
 		$self->debugging_rectangles($gd,scalar $panel->boxes)
 		    if DEBUGGING_RECTANGLES;
 		warn "render titles($label): ",time()-$time," seconds " if BENCHMARK;
@@ -1656,6 +1668,8 @@ sub subtrack_select_filter {
     return $stt->filter_feature_sub;
 }
 
+
+# this routine is too long and needs to be modularized
 sub add_features_to_track {
   my $self = shift;
   my %args = @_;
@@ -1794,14 +1808,6 @@ sub add_features_to_track {
 							       -seq_id     => $segment->seq_id,
 		  );
 	      $has_subtracks{$l}++;
-
-	      if ($source->setting($l=>'subtrack single plot')) {
-	          $tracks->{$l}->configure(
-	                 -scale     => 'none',
-	                 -no_grid   => 1,
-	          );
-	      }
-
 	      $groups{$l}{$id}->add_segment($feature);
 	      next;
 	  }
@@ -1836,39 +1842,8 @@ sub add_features_to_track {
 	    foreach @ids
     }
 
-    if ($source->setting($l=>'subtrack single plot')) {
-        my $tempFeature = Bio::Graphics::Feature->new(-type       => 'group',
-                                                      -start      => $segment->start,
-                                                      -end        => $segment->end,
-                                                      -seq_id     => $segment->seq_id,
-                      );
-        my $tempSubFeature = Bio::Graphics::Feature->new(-type       => 'scale',
-                                                         -scale      => 'three',
-                                                         -name       => 'scales',
-                                                         -start      => $segment->start,
-                                                         -end        => $segment->end,
-                                                         -seq_id     => $segment->seq_id,
-                      );
-        $tempFeature->add_segment(($tempSubFeature));
-        $track->add_feature($tempFeature);
-        
-        for my $f (values %$g) {
-            my @colours = ( qw(aqua black blue fuchsia gray green lime maroon navy olive purple red silver teal yellow) );
-            my @subFeatures = $f->get_SeqFeatures;
-            my $subf = $subFeatures[0];
-            if ($subf) {
-                my $feature_colour = $colours[rand @colours];
-                $subf->{attributes}{'bgcolor'} = $feature_colour;
-                $subf->{attributes}{'labelcolor'} = $feature_colour;
-            }
-            $track->add_feature($f);
-        }
-    } else {
-        $track->add_feature($_) foreach values %$g;
-    }
-
+    $track->add_feature($_) foreach values %$g;
     $feature_count{$l} += keys %$g;
-
   }
 
   # now reconfigure the tracks based on their counts
@@ -1900,14 +1875,18 @@ sub add_features_to_track {
 					       $max_labels,
 					       $length);
 
-    $tracks->{$l}->configure(-bump        => ($has_subtracks{$l} && ($source->setting($l=>'subtrack single plot'))) ? 0 : $do_bump,
+    $tracks->{$l}->configure(-bump        => $do_bump,
 			     -label       => $do_label,
 			     -description => $do_description,
 			      );
-    $tracks->{$l}->configure(-connector  => 'none') if !$do_bump;
+    $tracks->{$l}->configure(-label         => 0     ) if !$do_bump;
     $tracks->{$l}->configure(-bump_limit    => $limit)
       if $limit && $limit > 0;
 
+    # essentially make label invisible if we are going to get the label position
+    $tracks->{$l}->configure(-fontcolor   => 'white:0.0') 
+	if $tracks->{$l}->parts->[0]->record_label_positions;
+
     if (eval{$tracks->{$l}->features_clipped}) { # may not be present in older Bio::Graphics
 	my $max       = $tracks->{$l}->feature_limit;
 	my $count     = $tracks->{$l}->feature_count;
@@ -2125,6 +2104,23 @@ sub segment_coordinates {
   return ($seg_start,$seg_stop,$flip);
 }
 
+# this returns semantically-correct override configuration
+# as a hash ref
+sub override_settings {
+    my $self  = shift;
+    my $label = shift;
+    my $source            = $self->source;
+    my $state             = $self->settings;
+    my $length            = eval {$self->segment->length} || 0;
+    my $is_summary        = $source->show_summary($label,$length,$state);
+    my $semantic_override = Bio::Graphics::Browser2::Render->find_override_region(
+	$state->{features}{$label}{semantic_override},
+	$length);
+    return $is_summary           ? $state->{features}{$label}{summary_override}
+                                 : $semantic_override ? $state->{features}{$label}{semantic_override}{$semantic_override}
+                                 : {};
+}
+
 =head2 create_track_args()
 
   @args = $self->create_track_args($label,$args);
@@ -2144,19 +2140,14 @@ sub create_track_args {
   my $lang            = $self->language;
 
   my $is_summary      = $source->show_summary($label,$length,$self->settings);
-  my $state            = $self->settings;
-
-  my $semantic_override = Bio::Graphics::Browser2::Render->find_override_region(
-      $state->{features}{$label}{semantic_override},
-      $length);
-  my $override  = $is_summary           ? $state->{features}{$label}{summary_override}
-                   : $semantic_override ? $state->{features}{$label}{semantic_override}{$semantic_override}
-                   : {};
+  my $overlaps        =    ($self->settings->{features}{$label}{options}||0) == 4
+                        || ($source->semantic_setting($label => 'bump',$length)||'') eq 'overlap';
 
+  my $override        = $self->override_settings($label);
   my @override        = map {'-'.$_ => $override->{$_}} keys %$override;
 
   push @override,(-feature_limit => $override->{limit}) if $override->{limit};
-  push @override,(-record_label_positions => 0) unless $args->{section} && $args->{section} eq 'detail';
+  push @override,(-opacity => 1.0) unless $overlaps;
 
   my @summary_args = ();
   if ($is_summary) {
@@ -2174,7 +2165,7 @@ sub create_track_args {
   push @default_args,(-key   => $label)        unless $label =~ /^\w+:/;
   push @default_args,(-hilite => $hilite_callback) if $hilite_callback;
 
-  if ($self->subtrack_manager($label)) {
+  if (my $stt = $self->subtrack_manager($label)) {
       push @default_args,(-connector   => '');
       my $left_label = 
 	  $source->semantic_setting($label=>'label_position',$length)||'' eq 'left';
@@ -2187,8 +2178,9 @@ sub create_track_args {
       push @default_args,(
 	  -group_label          => $group_label||0,
 	  -group_label_position => $left_label ? 'top' : 'left',
-	  -group_subtracks      => $source->setting($label=>'subtrack single plot') ? 0 : 1,
+	  -group_subtracks      => !$overlaps,
       );
+      push @default_args,$stt->track_args;
   }
 
   my @args;
@@ -2221,6 +2213,7 @@ sub create_track_args {
   if (my $stt = $self->subtrack_manager($label)) {
       my $sub = $stt->sort_feature_sub;
       push @args,(-sort_order => $sub);
+#      push @args,(-color_series => 1) if $overlaps;
   }
 
   return @args;
@@ -2330,8 +2323,7 @@ sub do_bump {
       :  $option == 1 ? 0
       :  $option == 2 ? 1
       :  $option == 3 ? 1
-      :  $option == 4 ? 2
-      :  $option == 5 ? 2
+      :  $option == 4 ? 'overlap'
       :  0;
 }
 
@@ -2348,10 +2340,13 @@ sub do_label {
   my $conf_label        = $source->semantic_setting($track_name => 'label',$length);
   $conf_label           = 1 unless defined $conf_label;
 
+  my $glyph             = $source->semantic_setting($track_name => 'glyph',$length) || 'generic';
+  my $overlap_label     = $glyph =~ /xyplot|vista|wiggle|density/;
+
   $option ||= 0;
   return  $option == 0 ? $maxed_out && $conf_label
         : $option == 3 ? $conf_label || 1
-	: $option == 5 ? $conf_label || 1
+	: $option == 4 ? ($overlap_label ? $conf_label : 0)
         : 0;
 }
 
